import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/modals/balance.dart';

abstract class PaymentBalanceEvent {}

class PaymentBalanceCheckEvent extends PaymentBalanceEvent {}

class PaymentBalanceAddEvent extends PaymentBalanceEvent {
  final Amount amount;

  PaymentBalanceAddEvent(this.amount);
}

abstract class PaymentBalanceState {}

class PaymentBalanceSuccessState extends PaymentBalanceState {
  final PaymentBalance balance;

  PaymentBalanceSuccessState(this.balance);
}

class PaymentBalanceLoadingState extends PaymentBalanceState {}

class PaymentBalanceErrorState extends PaymentBalanceState {
  final String error;

  PaymentBalanceErrorState(this.error);
}

class PaymentBalanceInitialState extends PaymentBalanceState {}

class PaymentBalanceBloc
    extends Bloc<PaymentBalanceEvent, PaymentBalanceState> {
  final PaymentRepository paymentRepository;
  PaymentBalanceBloc(this.paymentRepository)
      : super(PaymentBalanceInitialState());

  @override
  Stream<PaymentBalanceState> mapEventToState(
      PaymentBalanceEvent event) async* {
    if (event is PaymentBalanceCheckEvent) {
      yield PaymentBalanceLoadingState();
      var response = await paymentRepository.getBalance();
      if (response.isSuccess) {
        yield PaymentBalanceSuccessState(response.data);
      } else {
        yield PaymentBalanceErrorState(response.error);
      }
    }
    if (event is PaymentBalanceAddEvent) {
      yield PaymentBalanceLoadingState();
      var response = await paymentRepository.addAmount(event.amount);
      if (response.isSuccess) {
        add(PaymentBalanceCheckEvent());
      } else {
        yield PaymentBalanceErrorState(response.error);
        add(PaymentBalanceCheckEvent());
      }
    }
  }
}
