import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';

class PaymentHandler {
  final BuildContext context;

  PaymentHandler.of(this.context);

  Future<AppResponse<PaymentResponse>> pay(PaymentRequest request) async {
    var canPay = await showModalBottomSheet(
        backgroundColor: Colors.transparent,
        context: context,
        builder: (context) => PaymentConfirmationWidget(
              request: request,
              onConfirmed: () {
                Navigator.of(context).pop(true);
              },
            ));
    if (canPay is bool && canPay) {
      var method = await Navigator.of(context)
          .push(MaterialPageRoute(builder: (context) => PaymentMethodScreen()));
      if (method is PaymentMethod) {
        var cancelFunction =
            await AppUIHelper.of(context).showLoadingToast("Making Payment...");
        var response = await BlocProvider.of<PaymentMethodListBloc>(context)
            .paymentRepository
            .payAmount(request.copyWith(methodId: method.id));
        cancelFunction();
        AppUIHelper.of(context).showToast(text: "Payment done!");
        return response;
      }
    }
    return AppResponse.named(error: "Payment Cancelled");
  }

  Future<AppResponse<bool>> addMoney(Amount amount) async {
    var method = await chooseMethod();
    if (method is PaymentMethod) {
      var cancelFunction =
          await AppUIHelper.of(context).showLoadingToast("Adding Funds...");
      var response = await BlocProvider.of<PaymentMethodListBloc>(context)
          .paymentRepository
          .addAmount(amount);
      cancelFunction();
      if (response.isSuccess)
        AppUIHelper.of(context).showToast(text: "Funds Added!");
      else {
        AppUIHelper.of(context).showToast(text: "Error ${response.error}");
      }
      return response;
    }
    return AppResponse.named(error: "Please choose payment method");
  }

  Future<PaymentMethod> chooseMethod() async {
    var method = await Navigator.of(context)
        .push(MaterialPageRoute(builder: (context) => PaymentMethodScreen()));
    if (method is PaymentMethod) {
      return method;
    }
    return method;
  }

  Future<void> addBankAccount() async {
    var bank = await Navigator.of(context)
        .push(MaterialPageRoute(builder: (context) => BankAddScreen()));
    if (bank is PaymentBank) {
      BlocProvider.of<PaymentMethodListBloc>(context)
          .add(PaymentMethodAddEvent(bank));
    }
  }
}
