import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:ocg_app/ocg_app.dart';

part 'method.g.dart';

enum PaymentType { Card, Wallet, Bank }

@JsonSerializable(explicitToJson: true)
class PaymentMethod extends Equatable {
  final String id;
  @JsonKey(toJson: convertToInt)
  final PaymentType type;

  PaymentMethod(this.id, this.type);
  @override
  List<Object> get props => [id, type];

  static convertToInt(PaymentType type) => type.index;
}

@JsonSerializable(explicitToJson: true)
class PaymentBank extends PaymentMethod {
  final String holderName;
  final String ifsc;
  final String branch;
  final String account;

  PaymentBank(String id, this.holderName, this.ifsc, this.branch, this.account)
      : super(id, PaymentType.Bank);

  PaymentBank.named(
      {String id, this.holderName, this.ifsc, this.branch, this.account})
      : super(id, PaymentType.Bank);

  PaymentBank copyWith(
      {String id,
      String holderName,
      String branch,
      String account,
      String ifsc}) {
    return PaymentBank.named(
        account: account ?? this.account,
        branch: branch ?? this.branch,
        id: id ?? this.id,
        ifsc: ifsc ?? this.ifsc,
        holderName: holderName ?? this.holderName);
  }

  Map<String, dynamic> toJson() => _$PaymentBankToJson(this);

  factory PaymentBank.fromJson(json) => _$PaymentBankFromJson(json);
}

@JsonSerializable(explicitToJson: true)
class PaymentCard extends PaymentMethod {
  final String id;
  final String cardNo;
  final String holder;
  final DateTime expiryDate;
  final String cvv;
  final String logo;
  final int amount;
  final String currency;
  @JsonKey(fromJson: JsonHelper.colorFromJson, toJson: JsonHelper.colorToJson)
  final Color color;

  PaymentCard(this.id, this.cardNo, this.holder, this.expiryDate, this.cvv,
      this.logo, this.color, this.amount, this.currency)
      : super(id, PaymentType.Card);

  PaymentCard.named(
      {this.id,
      this.cardNo,
      this.holder,
      this.expiryDate,
      this.cvv,
      this.logo,
      this.color,
      this.amount,
      this.currency})
      : super(id, PaymentType.Card);

  String get secretCardNo {
    var letters = [];
    for (int i = 0; i < cardNo.length;) {
      letters.add(cardNo.substring(i, ((i ~/ 4) + 1) * 4));
      i += 4;
    }
    var fakeNo = "";
    for (int i = 0; i < letters.length; i++) {
      if (i == letters.length - 1) {
        fakeNo += letters[i];
        break;
      }
      fakeNo += "****   ";
    }
    return fakeNo;
  }

  PaymentCard copyWith(
      {String id,
      String cardNo,
      String holder,
      DateTime expiryDate,
      String cvv,
      String logo,
      Color color,
      int amount,
      String currency}) {
    return PaymentCard.named(
        id: id ?? this.id,
        cardNo: cardNo ?? this.cardNo,
        color: color ?? this.color,
        cvv: cvv ?? this.cvv,
        expiryDate: expiryDate ?? this.expiryDate,
        holder: holder ?? this.holder,
        logo: logo ?? this.logo,
        amount: amount ?? this.amount,
        currency: currency ?? this.currency);
  }
}

@JsonSerializable(explicitToJson: true)
class PaymentWallet extends PaymentMethod {
  final String id;
  final String name;
  final String logo;
  final int amount;
  final String currency;

  PaymentWallet(this.id, this.name, this.logo, this.amount, this.currency)
      : super(id, PaymentType.Wallet);

  PaymentWallet.named(
      {this.id, this.name, this.logo, this.amount, this.currency})
      : super(id, PaymentType.Wallet);

  PaymentWallet copyWith({
    String id,
    String name,
    String logo,
    int amount,
    String currency,
  }) {
    return PaymentWallet.named(
        id: id ?? this.id,
        name: name ?? this.name,
        logo: logo ?? this.logo,
        amount: amount ?? this.amount,
        currency: currency ?? this.currency);
  }
}
