import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/metadata/form_style.dart';
import 'package:ocg_payment/src/metadata/meta_text.dart';
import 'package:ocg_payment/src/widgets/text_field.dart';

class BankForm extends StatefulWidget {
  final Function(PaymentBank bank) onSubmit;
  final Widget actionBtn;

  BankForm({Key key, this.onSubmit, this.actionBtn}) : super(key: key);

  @override
  _BankFormState createState() => _BankFormState();
}

class _BankFormState extends State<BankForm> {
  PaymentBank _bank;
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();

  @override
  void initState() {
    super.initState();
    _bank = PaymentBank.named();
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          TextFieldLabelWidget(
            labelText: MetaText.ifsc,
            textInputType: TextInputType.text,
            labelStyle: FormStyle.addBankAccountLabelStyle,
            focusedBorder: FormStyle.addBankFocusedBorder,
            enabledBorder: FormStyle.addBankEnabledBorder,
            onChanged: (val) {
              _bank = _bank.copyWith(ifsc: val);
            },
            validator: (val) => InputHelper.isBlank(val)
                ? "Please enter " + MetaText.ifsc
                : null,
          ),
          TextFieldLabelWidget(
            labelText: MetaText.accountNumber,
            textInputType: TextInputType.number,
            labelStyle: FormStyle.addBankAccountLabelStyle,
            focusedBorder: FormStyle.addBankFocusedBorder,
            enabledBorder: FormStyle.addBankEnabledBorder,
            onChanged: (val) {
              _bank = _bank.copyWith(account: val);
            },
            validator: (val) =>
                InputHelper.isBlank(val) ? "Please enter account number" : null,
          ),
          TextFieldLabelWidget(
            labelText: MetaText.yourName,
            textInputType: TextInputType.text,
            labelStyle: FormStyle.addBankAccountLabelStyle,
            focusedBorder: FormStyle.addBankFocusedBorder,
            enabledBorder: FormStyle.addBankEnabledBorder,
            onChanged: (val) {
              _bank = _bank.copyWith(holderName: val);
            },
            validator: (val) => InputHelper.isBlank(val)
                ? "Please enter " + MetaText.yourName
                : null,
          ),
          SizedBox(
            height: 18,
          ),
          widget.actionBtn != null
              ? GestureDetector(
                  onTap: _onSubmit,
                  child: widget.actionBtn,
                )
              : RoundedButton("Continue", onTap: _onSubmit)
        ],
      ),
    );
  }

  void _onSubmit() {
    if (_formKey.currentState.validate()) {
      widget.onSubmit(_bank);
    }
  }
}
