import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';

class PaymentCardWidget extends StatelessWidget {
  final PaymentCard card;
  final bool isSelected;
  final Function(PaymentCard card, bool isSelected) onSelected;

  const PaymentCardWidget(
      {Key key, @required this.card, this.isSelected = false, this.onSelected})
      : super(key: key);

  Widget build(BuildContext context) {
    return LayoutBuilder(builder: (context, constraints) {
      double width = constraints.biggest.width;
      return Container(
        child: EaseInWidget(
          child: Container(
            decoration: BoxDecoration(
                border: Border.all(
                  style: BorderStyle.solid,
                  color: Colors.black12,
                ),
                color: isSelected ? Colors.white : Color(0xFFF9F8FD),
                borderRadius: BorderRadius.all(Radius.circular(8)),
                boxShadow: [
                  BoxShadow(
                    color: Color(0xFFE4E4E4).withOpacity(0.3),
                    blurRadius: 12.0,
                    spreadRadius: 0.1,
                    offset: Offset(
                      4.0,
                      4.0,
                    ),
                  )
                ]),
            padding:
                EdgeInsets.symmetric(horizontal: width * 0.05, vertical: 15),
            child: Row(
              children: [
                Icon(
                  Icons.credit_card,
                  size: 32,
                  color: Colors.black45,
                ),
                SizedBox(
                  width: 18,
                ),
                Expanded(
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        "${card.secretCardNo}",
                        style: TextStyle(
                            fontSize: 16,
                            color: Color(0xFF0D0B22),
                            fontWeight: FontWeight.w600),
                      ),
                      SizedBox(
                        height: 4,
                      ),
                      Text(
                        "${DateHelper.beautifyDate(card.expiryDate)}",
                        style:
                            TextStyle(fontSize: 14, color: Color(0xFF565656)),
                      )
                    ],
                  ),
                ),
                SizedBox(
                  width: 18,
                ),
                isSelected
                    ? Icon(
                        Icons.check_circle,
                        color: Colors.green,
                        size: 28,
                      )
                    : Container(
                        width: 0,
                        height: 0,
                      )
              ],
            ),
          ),
          onTap:
              onSelected == null ? null : () => onSelected(card, !isSelected),
        ),
      );
    });
  }
}
